@@ -9,6 +9,7 @@ from wizwalker.memory import Window
 handleQuestCollection = True
 is_tab = '\t'.__eq__
 
+
 @logger.catch()
 async def go_through_dialog(p):
     while await p.is_in_dialog():
@@ -300,9 +301,9 @@ async def gateTypeDifferentiation(x, y, z, p, zoneAccessType):
             await p.send_key(Keycode.X, 0.1)
             await p.send_key(Keycode.X, 0.1)
             await p.send_key(Keycode.X, 0.1)
-        logger.debug("Waiting a long ass time for the mouth thing to open")
+        logger.info("Waiting a long time for the mouth thing to open")
         await asyncio.sleep(20)
-        logger.debug("If you haven't changed zones by now, manually turn on the obelisks and walk to the zone gate.  The script should continue after you change zones")
+        logger.info("If you haven't changed zones by now, manually turn on the obelisks and walk to the zone gate.  The script should continue after you change zones")
 
         # Zone Change - Tomb of Storms
         # Teleport to front of mouth thing
@@ -718,7 +719,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
         currentWorldStackDestinations = await createStack(currentWorld)
 
         # traverse to the first zone in the world (or wherever the zone door is located)
-        logger.debug(f'Returning to Spiral Door in: {zoneContainingZoneDoor}')
+        logger.info(f'Returning to Spiral Door in: {zoneContainingZoneDoor}')
         await goToDestination(p, zoneContainingZoneDoor, currentWorld, currentWorldStackDestinations, interactiveTeleportersOriginal)
 
         # teleport to the zone door
@@ -726,7 +727,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
         await asyncio.sleep(2)
 
         # teleport to new world
-        logger.debug(f'User in wrong world - heading to {destinationWorld}')
+        logger.info(f'User in wrong world - heading to {destinationWorld}')
         bigStackDestinations = await goToNewWorld(p, destinationWorld)
         p1WorldName = destinationWorld
 
@@ -744,7 +745,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
             i += 1
 
         if currentZoneInZoneMap == False:
-            logger.debug(f'Zone not found in zonemap - returning to Hub to reconnect')
+            logger.info(f'Zone not found in zonemap - returning to Hub to reconnect')
             # these have to be hardcoded
             # if a player recalls to a dungeon, then attempts to return to the hub, they go through two zone changes: once to the hub, second back to the zone they were in before recalling
             # this makes it impossible to account for zone changes without having ridiculously long sleeps or hardcoded zone names
@@ -882,7 +883,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
             # traverse down the current path back to the common zone, then stop
             i = len(pathToCurrentZoneStack) - 1
             if len(pathToCurrentZoneStack) > 0:
-                logger.debug('Going back to most recent common zone')
+                logger.info('Going back to most recent common zone')
                 while i >= 0:
 
                     lines = iter(linesOriginal)
@@ -917,7 +918,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
         # now traverse to the destination
         i = 0
         if len(pathToDestinationStack) != 0:
-            logger.debug(f'Heading to destination zone {destinationZone}')
+            logger.info(f'Heading to destination zone {destinationZone}')
 
         while i < len(pathToDestinationStack):
 
@@ -958,7 +959,7 @@ async def goToDestination(p, destinationZone, p1WorldName, bigStackDestinations,
             zone = await p.zone_name()
             if zone != destinationZone.strip():
                 if p1WorldName in ['Empyrea', 'Karamelle', 'Lemuria']:
-                    logger.debug(f'Physical gate not found.  Attempting interactive teleport')
+                    logger.info(f'Physical gate not found.  Attempting interactive teleport')
                     await teleportToInteractiveTeleportIfAvailable(p, zone, zoneTo, interactiveTeleportersOriginal)
 
 
@@ -974,7 +975,7 @@ async def toZone(clients, destinationZone):
 
     await asyncio.gather(*[goToDestination(p, destinationZone, worldName, bigStackDestinations, interactiveTeleportersOriginal) for p in clients])
 
-    logger.debug(f'reached destination zone: {destinationZone}.')
+    logger.info(f'reached destination zone: {destinationZone}.')
 
 potion_ui_buy = [
     "fillallpotions",
@@ -986,7 +987,7 @@ potion_ui_buy = [
     "exit"
 ]
 
-# Credit to Notfaj and Slackaduts for this function from UniversalBotSF
+# Credit to Notfaj and Slackaduts for the majority of this function from UniversalBotSF
 @logger.catch()
 async def refillPotions(clients):
     await toZone(clients, 'WizardCity/WC_Ravenwood_Teleporter')
@@ -1034,6 +1035,7 @@ async def refillPotions(clients):
         await client.send_key(Keycode.PAGE_UP, 0.1)
         await client.wait_for_zone_change()
 
+
 @logger.catch()
 async def main(clientHandler):
     clientHandler.get_new_clients()
@@ -1044,10 +1046,10 @@ async def main(clientHandler):
 
     # Hook activation
     for p in clients:
-        logger.debug(f"[{p.title}] Activating Hooks")
+        logger.info(f"[{p.title}] Activating Hooks")
         await p.activate_hooks()
 
-    logger.debug('Hooks activated!')
+    logger.info('Hooks activated!')
 
     
     try:
